@@ -55,6 +55,15 @@ class WordpressItemTests(TestCase):
             "wp:post_type": "post",
             "link": "",
         }
+        self.no_title = {
+            "wp:post_name": "no-title",
+            "wp:post_date_gmt": "2017-03-12 17:53:57",
+            "wp:post_modified_gmt": "2018-12-04 11:49:24",
+            "content:encoded": body_html,
+            "wp:post_id": "1000",
+            "wp:post_type": "post",
+            "link": "http://www.example.com",
+        }
 
     def test_all_fields_with_good_data(self):
         wordpress_item = WordpressItem(self.good_node, self.logger)
@@ -106,6 +115,15 @@ class WordpressItemTests(TestCase):
         self.assertIsInstance(latest_revision_created_at, datetime)
         self.assertEqual(wp_link, "")
 
+    def test_no_title_faked(self):
+        wordpress_item = WordpressItem(self.no_title, self.logger)
+        title = wordpress_item.cleaned_data["title"]
+
+        self.assertEqual(
+            self.no_title["wp:post_id"], "1000"
+        )  # just a fixture regression test
+        self.assertEqual(title, f"no-title-available-1000")
+
 
 @override_settings(
     WAGTAIL_WORDPRESS_IMPORTER_SOURCE_DOMAIN="http://localhost:8000",
@@ -458,7 +476,6 @@ class TestWordpressItemPrefilterOverride(TestCase):
         self.assertEqual(output[0], "foo bar baz")
         self.assertEqual(output[1], {"foo": "bar"})
 
-
     @override_settings(
         WAGTAIL_WORDPRESS_IMPORT_PREFILTERS=[
             {
